@@ -87,8 +87,10 @@ def deploy(config_file, manager_path, check, dry_run):
         config=config, filepath=config_file, manager_path=manager_path, dry_run=dry_run
     )
     exception = None
+    Printer.print_success(
+        "Polyaxon `{}` deployment file is valid.".format(config.deployment_chart)
+    )
     if check:
-        Printer.print_success("Polyaxon deployment file is valid.")
         try:
             manager.check()
         except Exception as e:
@@ -141,8 +143,10 @@ def upgrade(config_file, manager_path, check, dry_run):
         config=config, filepath=config_file, manager_path=manager_path, dry_run=dry_run
     )
     exception = None
+    Printer.print_success(
+        "Polyaxon `{}` deployment file is valid.".format(config.deployment_chart)
+    )
     if check:
-        Printer.print_success("Polyaxon deployment file is valid.")
         try:
             manager.check()
         except Exception as e:
