@@ -16,6 +16,7 @@
 
 from marshmallow import ValidationError, fields, validate, validates_schema
 
+from polyaxon.deploy.schemas.auth import AuthSchema
 from polyaxon.deploy.schemas.deployment_types import DeploymentCharts, DeploymentTypes
 from polyaxon.deploy.schemas.email import EmailSchema
 from polyaxon.deploy.schemas.ingress import IngressSchema
@@ -223,6 +224,10 @@ class DeploymentSchema(BaseCamelSchema):
     security_context = fields.Nested(SecurityContextSchema, allow_none=True)
     external_services = fields.Nested(ExternalServicesSchema, allow_none=True)
     debug_mode = fields.Bool(allow_none=True)
+    organization_key = fields.Str(allow_none=True)
+    auth = fields.Nested(AuthSchema, allow_none=True)
+    js_offline = fields.Bool(allow_none=True)
+    ui_enabled = fields.Bool(allow_none=True)
 
     # Pending validation
     dns = fields.Raw(allow_none=True)
@@ -272,6 +277,7 @@ class DeploymentSchema(BaseCamelSchema):
                 ldap=data.get("ldap"),
                 intervals=data.get("intervals"),
                 metrics=data.get("metrics"),
+                organization_key=data.get("organization_key"),
             )
 
 
@@ -332,7 +338,11 @@ class DeploymentConfig(BaseConfig):
         security_context=None,
         external_services=None,
         debug_mode=None,
+        auth=None,
+        organization_key=None,
         dns=None,
+        js_offline=None,
+        ui_enabled=None,
     ):
         validate_deployment_chart(
             deployment_chart=deployment_chart, agent=agent, environment=environment,
@@ -349,7 +359,7 @@ class DeploymentConfig(BaseConfig):
         )
         validate_gateway(gateway)
         self.deployment_type = deployment_type
-        self.deployment_chart = deployment_chart
+        self.deployment_chart = deployment_chart or DeploymentCharts.PLATFORM
         self.deployment_version = deployment_version
         self.namespace = namespace
         self.rbac = rbac
@@ -401,6 +411,10 @@ class DeploymentConfig(BaseConfig):
         self.security_context = security_context
         self.external_services = external_services
         self.debug_mode = debug_mode
+        self.auth = auth
+        self.organization_key = organization_key
+        self.js_offline = js_offline
+        self.ui_enabled = ui_enabled
         if self.deployment_chart == DeploymentCharts.AGENT:
             wrong_agent_deployment_keys(
                 polyaxon_secret=polyaxon_secret,
@@ -424,4 +438,5 @@ class DeploymentConfig(BaseConfig):
                 ldap=ldap,
                 intervals=intervals,
                 metrics=metrics,
+                organization_key=organization_key,
             )
