@@ -185,7 +185,6 @@ class AgentServiceConfig(Service):
 
 
 class ApiServiceSchema(ServiceSchema):
-    is_control_plane = fields.Bool(allow_none=True)
     service = fields.Dict(allow_none=True)
 
     @staticmethod
@@ -205,7 +204,6 @@ class ApiServiceConfig(Service):
         replicas=None,
         concurrency=None,
         resources=None,
-        is_control_plane=None,
         service=None,
     ):
         super().__init__(
@@ -217,7 +215,6 @@ class ApiServiceConfig(Service):
             concurrency=concurrency,
             resources=resources,
         )
-        self.is_control_plane = is_control_plane
         self.service = service
 
 
