@@ -30,6 +30,7 @@ from polyaxon.cli.config import config
 from polyaxon.cli.dashboard import dashboard
 from polyaxon.cli.init import init
 from polyaxon.cli.operations import ops
+from polyaxon.cli.port_forward import port_forward
 from polyaxon.cli.projects import project
 from polyaxon.cli.run import run
 from polyaxon.cli.upload import upload
@@ -121,6 +122,7 @@ cli.add_command(upload)
 cli.add_command(run)
 cli.add_command(dashboard)
 cli.add_command(admin)
+cli.add_command(port_forward)
 cli.add_command(completion)
 if settings.CLIENT_CONFIG.is_ops:
 
