@@ -44,6 +44,7 @@ def convert(
     polyaxon_init: V1PolyaxonInitContainer = None,
     converters: Dict[str, Any] = CORE_CONVERTERS,
     internal_auth: bool = False,
+    default_auth: bool = False,
 ) -> Dict:
     if compiled_operation.has_pipeline:
         raise PolyaxonCompilerError(
@@ -76,6 +77,7 @@ def convert(
             connection_by_names=connection_by_names,
             secrets=secrets,
             config_maps=config_maps,
+            default_auth=default_auth,
         )
         api = k8s_client.ApiClient()
         return api.sanitize_for_serialization(resource)
