@@ -33,11 +33,11 @@ class JobConverter(JobMixin, BaseConverter):
         connection_by_names: Dict[str, V1ConnectionType],
         secrets: Optional[Iterable[V1K8sResourceType]],
         config_maps: Optional[Iterable[V1K8sResourceType]],
-        is_resume: bool = False,
+        default_auth: bool = False,
     ) -> Dict:
         job = compiled_operation.run  # type: V1Job
         plugins = compiled_operation.plugins or V1Plugins()
-        contexts = PluginsContextsSpec.from_config(plugins)
+        contexts = PluginsContextsSpec.from_config(plugins, default_auth=default_auth)
         replica_spec = self.get_replica_resource(
             plugins=plugins,
             contexts=contexts,
@@ -51,7 +51,6 @@ class JobConverter(JobMixin, BaseConverter):
             connection_by_names=connection_by_names,
             secrets=secrets,
             config_maps=config_maps,
-            is_resume=is_resume,
         )
         return get_job_custom_resource(
             namespace=self.namespace,
