@@ -75,7 +75,7 @@ class TestDeploymentConfig(BaseTestCase):
         assert config.global_replicas is None
         assert config.global_concurrency is None
         assert config.api.replicas == 3
-        assert config.api.is_control_plane is None
+        assert config.organization_key is None
         assert config.scheduler.replicas == 3
         assert config.beat is None
         assert config.hooks is None
@@ -201,7 +201,7 @@ class TestDeploymentConfig(BaseTestCase):
         assert config.global_replicas is None
         assert config.global_concurrency is None
         assert config.api.replicas == 1
-        assert config.api.is_control_plane is True
+        assert config.organization_key == "some-key"
         assert config.scheduler.replicas == 1
         assert config.scheduler.celery.to_dict() == {
             "taskTrackStarted": False,
